==> savane-1.0.2.tar.gz: savane/frontend/php/sendmessage.php <==
<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: sendmessage.php,v 1.22 2004/03/26 18:45:45 yeupou Exp $
# 
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundatio
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "./include/pre.php";    

if (user_isloggedin()) 
{


  if ($touser) 
    {
      # Search infos in the database about the user
      $result=db_query("SELECT email,user_name FROM user WHERE user_id='$touser'");
      if (!$result || db_numrows($result) < 1) 
	{
	  exit_error('Error','Error - That user does not exist.');
	}
    } 
  else
    {
      exit_missing_param();
    } 


  if ($send_mail) 
    {
    
      if (!$subject || !$body || !$fromuser) 
	{
	  # Force them to enter all vars
	  exit_missing_param();
	}
      else 
	{
	  # Let sendmail_mail() figuring out real email addresses
	  sendmail_mail($fromuser, $touser, $subject, $body);
	  $HTML->header(array('title'=>'Message Sent'));
	  print html_feedback_top($GLOBALS['feedback']);
	  $HTML->footer(array());
	  exit;
	}
    
    } 
  else 
    {
    
      $HTML->header(array('title'=>'Send a message'));
      sendmail_form_message($PHP_SELF, $touser);
      $HTML->footer(array());
    
    }

} else {
  
  # Not logged-in, no mail to be sent.
  exit_not_logged_in();  
  
}


?>

==> savane-1.0.4.tar.gz: savane/frontend/php/sendmessage.php <==
<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: sendmessage.php,v 1.24 2004/07/03 18:22:03 yeupou Exp $
# 
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundatio
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "./include/pre.php";
    
# lorenzo lorenzohgh@tuxedo-es.org 
# Declaring variables BY method 

if ($_POST['touser'])
   { 
   $touser = $_POST['touser']; 
   }
elseif ($_GET['touser'])
   { 
   $touser = $_GET['touser']; 
   }
   if ($_POST['send_mail'])
   { 
   $send_mail = $_POST['send_mail']; 
   }
elseif ($_GET['send_mail'])
   { 
   $send_mail = $_GET['send_mail']; 
   }
   if ($_POST['subject'])
   { 
   $subject = $_POST['subject']; 
   }
elseif ($_GET['subject'])
   { 
   $subject = $_GET['subject']; 
   }
   if ($_POST['body'])
   { 
   $body = $_POST['body']; 
   }
elseif ($_GET['body'])
   { 
   $body = $_GET['body']; 
   }
if ($_POST['feedback'])
   { 
   $feedback = $_POST['feedback']; 
   }
elseif ($_GET['feedback'])
   { 
   $feedback = $_GET['feedback']; 
   }     

if (user_isloggedin()) 
{


  if ($touser) 
    {
      # Search infos in the database about the user
      $result=db_query("SELECT email,user_name FROM user WHERE user_id='$touser'");
      if (!$result || db_numrows($result) < 1) 
	{
	  exit_error('Error',_('That user does not exist'));
	}
    } 
  else
    {
      exit_missing_param();
    } 

  
  if ($send_mail) 
    {
    
      if (!$subject || !$body || !$fromuser) 
	{
	  # Force them to enter all vars
	  exit_missing_param();
	}
      else 
	{
	  # Let sendmail_mail() figuring out real email addresses
	  sendmail_mail($fromuser, $touser, $subject, $body);
	  $HTML->header(array('title'=>_('Message Sent')));
	  print html_feedback_top($GLOBALS['feedback']);
	  $HTML->footer(array());
	  exit;
	}
    
    } 
  else 
    {
    
      $HTML->header(array('title'=>_('Send a message')));
      sendmail_form_message($PHP_SELF, $touser);
      $HTML->footer(array());
    
    }

} else {
  
  # Not logged-in, no mail to be sent.
  exit_not_logged_in();  
  
}


?>
